@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cryptohash-conduit
 version: 0.1.1
-id: cryptohash-conduit-0.1.1-292d948fd9df89252796a0ce05c31679
-key: crypt_67H40h1wrfsLKr7aBSlXdM
+id: cryptohash-conduit-0.1.1-8353f97b6e24bf6f7d83facec1b53829
+key: crypt_2BHdyJ8T2kkKQJYFvKRGRJ
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -22,14 +22,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
-hs-libraries: HScryptohash-conduit-0.1.1-67H40h1wrfsLKr7aBSlXdM
+hs-libraries: HScryptohash-conduit-0.1.1-2BHdyJ8T2kkKQJYFvKRGRJ
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.13.1-9eaf94b1885f7c12e1eeebbc86766f62
-    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
+    conduit-extra-1.1.13.1-b0a6afe4d52c8bc50dff37cca54ee4a6
+    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
 haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
